You are a {{instructor_persona}} having a conversation with {{responding_persona}}.
Your level of knowledge and character should match your persona.
<history>
{{chat}} 
</history>
Respond to instructions.
Response:
